@@ -248,7 +248,7 @@ find_pixmap_path (const char* pixmap_)
 #endif
 
 CardBox::
-CardBox ()
+CardBox (MainWindow& mwin_) : m_mwin (mwin_)
 {
 	trace_with_mask("CardBox::CardBox",GUITRACE);
 	Gtk::EventBox* evtbox = NULL;
@@ -259,21 +259,21 @@ CardBox ()
 		m_cdplayers [i] = NULL;
 	}
 
-	m_drawer_empty = Gdk::Pixbuf::create_from_file(
+	m_drawer_empty = Granule::create_from_file(
 		find_pixmap_path ("drawer_empty.png") CB_SHRINK_ICONS);
-	m_drawer_one   = Gdk::Pixbuf::create_from_file(
+	m_drawer_one   = Granule::create_from_file(
 		find_pixmap_path ("drawer_one.png")   CB_SHRINK_ICONS);
-	m_drawer_many  = Gdk::Pixbuf::create_from_file(
+	m_drawer_many  = Granule::create_from_file(
 		find_pixmap_path ("drawer_many.png")  CB_SHRINK_ICONS);
 
 	m_sched_green  = 
-		Gdk::Pixbuf::create_from_file(find_pixmap_path ("sched_green.png"));
+		Granule::create_from_file(find_pixmap_path ("sched_green.png"));
 	m_sched_grey   =
-		Gdk::Pixbuf::create_from_file(find_pixmap_path ("sched_grey.png"));
+		Granule::create_from_file(find_pixmap_path ("sched_grey.png"));
 	m_sched_red    = 
-		Gdk::Pixbuf::create_from_file(find_pixmap_path ("sched_red.png"));
+		Granule::create_from_file(find_pixmap_path ("sched_red.png"));
 	m_sched_yellow = 
-		Gdk::Pixbuf::create_from_file(find_pixmap_path ("sched_yellow.png"));
+		Granule::create_from_file(find_pixmap_path ("sched_yellow.png"));
 
 	for (i = 0; i < CARD_BOX_SIZE; i++) {
 		m_cbs.push_back (CardBoxIF ());
@@ -394,7 +394,7 @@ new_file ()
 		m_card_deck [i].set_name (i);
 		m_cdplayers [i] = new DeckPlayer (m_card_deck [i]);
 	}
-	MAINWIN->set_mw_name ();
+	m_mwin.set_mw_name ();
 }
 
 int
@@ -453,7 +453,7 @@ load (const string& fname_)
 
 	if (parse_xml_tree (parser, error_msg) == 0) {
 		m_fname = fname_;
-		MAINWIN->set_mw_name ();
+		m_mwin.set_mw_name ();
 		CONFIG->set_filesel_path (fname_);
 	}
 	else {
@@ -565,7 +565,7 @@ parse_xml_tree (const xmlDocPtr parser_, string error_msg_)
 			if (result == NULL) {
 				return -1;
 			}
-			deck_path = Glib::locale_from_utf8 ((const char*) result);
+			deck_path = Granule::locale_from_utf8 ((const char*) result);
 			xmlFree (result);
 
 			if (deck_path[0] != ASSA_DIR_SEPARATOR) {
@@ -681,7 +681,7 @@ save ()
 					deck_fname = abs_fname;
 				}
 				ret = xmlTextWriterWriteElement (writer, BAD_CAST "fromdeck",
-						 BAD_CAST Glib::locale_to_utf8 (deck_fname).c_str ());
+						 BAD_CAST Granule::locale_to_utf8 (deck_fname).c_str ());
 
 				ret = xmlTextWriterWriteElement (writer, BAD_CAST "expdate",
 						 BAD_CAST card_ref->get_expiration_str ().c_str ());
@@ -1026,7 +1026,7 @@ play_in_box_cb (GdkEventButton* event, int idx_)
 		emsg.run ();
 	}
 	else {
-		MAINWIN->play_in_box (idx_);
+		m_mwin.play_in_box (idx_);
 		set_expiration_light (idx_);
 	}
 	return true;
@@ -1094,7 +1094,7 @@ on_deck_dropped_cb (const Glib::RefPtr<Gdk::DragContext>& context_,
     /** Doesn't work - I get bogus pointer back! (investigate)
 	    Deck* src_deck = (Deck*)(selection_data_.get_data ());
 	*/
-	src_deck = MAINWIN->get_dnd_source ();
+	src_deck = m_mwin.get_dnd_source ();
 	add_deck_to_box (card_deck_index_, src_deck);
 	context_->drag_finish (false, false, drop_timestamp_);
 }
@@ -1127,7 +1127,7 @@ void
 CardBox::
 mark_as_modified () 
 { 
-	MAINWIN->go_state (Dirty); 
+	m_mwin.go_state (Dirty); 
 }
 
 
