@@ -59,12 +59,54 @@
 	t->set_justification (Gtk::JUSTIFY_LEFT);  \
 	t->set_accepts_tab (false);
 
-#define SET_CV_SCROLLWIN(w,t) \
-	w->set_flags (Gtk::CAN_FOCUS); \
-	w->set_shadow_type (Gtk::SHADOW_NONE); \
-	w->set_policy (Gtk::POLICY_ALWAYS, Gtk::POLICY_ALWAYS); \
-	w->property_window_placement ().set_value (Gtk::CORNER_TOP_LEFT); \
-	w->add (*t)
+static void 
+set_cv_scrollwin (Gtk::ScrolledWindow& win_, Gtk::Widget& widget_)
+{
+	win_.set_flags       (Gtk::CAN_FOCUS);
+	win_.set_shadow_type (Gtk::SHADOW_NONE);
+	win_.set_policy      (Gtk::POLICY_ALWAYS, Gtk::POLICY_ALWAYS); 
+#ifdef GLIBMM_PROPERTIES_ENABLED 
+	win_.property_window_placement ().set_value (Gtk::CORNER_TOP_LEFT);
+#else
+	win_.set_property ("window_placement", Gtk::CORNER_TOP_LEFT);
+#endif 
+
+/** Defeat Hildons' default theme and provide
+ *  our own visual border around Text Entry
+ */
+#ifdef IS_HILDON
+
+	Gtk::Frame* f = manage (new Gtk::Frame ());
+	f->set_border_width (1);
+    f->set_shadow_type  (Gtk::SHADOW_ETCHED_OUT);
+	f->set_label_align  (0, 0);
+	f->add (widget_);
+	win_.add (*f);
+#else
+	win_.add (widget_);
+#endif
+}
+
+/**
+ * Enclose Gtk::TextView in a visible box. Some default themes (hildon)
+ * blend the surrounding, so it is hard to see where the editable
+ * region lies.
+ */
+static Gtk::Widget*
+set_text_border (Gtk::Widget* widget_)
+{
+#ifdef IS_HILDON
+	Gtk::Frame* frame = manage (new Gtk::Frame ());
+	frame->set_border_width (1);
+    frame->set_shadow_type  (Gtk::SHADOW_ETCHED_OUT);
+	frame->set_label_align  (0, 0);
+	frame->add (*widget_);
+	return (frame);
+#else
+	return (widget_);
+#endif
+}
+
 
 /*------------------------------------------------------------------------------
 ** CardView class implementation
@@ -73,11 +115,6 @@
 CardView::
 CardView (VCard* card_) 
 	: 
-
-#ifdef IS_HILDON
-	Hildon::AppView ("Card View"),
-#endif
-
 	m_card          (card_),
 	m_syntax_error  (false),
 	m_keep_open     (false),
@@ -95,7 +132,7 @@ CardView (VCard* card_)
 	m_asb_text      (NULL),
 
 	m_edit_controls (NULL),
-	m_help_dialog   (*this)
+	m_help_dialog   (NULL)
 {
 	trace_with_mask("CardView::CardView(VCard&)",GUITRACE);
 
@@ -156,10 +193,12 @@ CardView (VCard* card_)
 
 	Gtk::VBox*  vbox_all;
 
+	/** The dialog setup
+	 */
 	set_title ("Card View");
 
 #ifdef IS_HILDON
-	set_size_request (672, 396);
+//	set_size_request (672, 396);
 #else
 	set_modal (true);  // very important - we're not protected from multi-clicks
 //	property_window_position ().set_value (Gtk::WIN_POS_CENTER);
@@ -169,7 +208,7 @@ CardView (VCard* card_)
 	Gdk::Geometry dp_geometry =	{ 240, 320,	240, 320, 240, 320,-1, -1, -1, -1};
 	set_geometry_hints (*this, dp_geometry, 
 				Gdk::HINT_MIN_SIZE | Gdk::HINT_MAX_SIZE | Gdk::HINT_BASE_SIZE);
-#else
+#else // DESKTOP
 	set_resizable (true);
 	set_icon_from_file (GRAPPDATDIR "/pixmaps/cardview_32x32.png");
 	Gdk::Rectangle geom = CONFIG->get_card_view_geometry ();
@@ -266,6 +305,22 @@ CardView (VCard* card_)
 	m_asf_text     ->modify_font (CONFIG->get_example_font ());
 	m_asb_text     ->modify_font (CONFIG->get_example_font ());
 
+#ifdef IS_HILDON
+	m_textbuf_ref [TV_FRONT] = Gtk::TextBuffer::create();
+	m_front_text->set_buffer (m_textbuf_ref [TV_FRONT]);
+
+	m_textbuf_ref [TV_BACK] = Gtk::TextBuffer::create();
+	m_back_text->set_buffer (m_textbuf_ref [TV_BACK]);
+
+	m_textbuf_ref [TV_EXAMPLE] = Gtk::TextBuffer::create();
+	m_example_text->set_buffer (m_textbuf_ref [TV_EXAMPLE]);
+
+	m_textbuf_ref [TV_ASF] = Gtk::TextBuffer::create();
+	m_asf_text->set_buffer (m_textbuf_ref [TV_ASF]);
+
+	m_textbuf_ref [TV_ASB] = Gtk::TextBuffer::create();
+	m_asb_text->set_buffer (m_textbuf_ref [TV_ASB]);
+#endif
 
 	/**----------------**
 	 **  Edit Controls **
@@ -310,7 +365,7 @@ CardView (VCard* card_)
 	m_cancel_button->set_relief (Gtk::RELIEF_NORMAL);
 	m_cancel_button->add (*alignment2);
 
-	/** [Count] Label
+	/** [Count] Label should be invisible
 	 */
 	m_count_button->set_focus_on_click (false);
 	m_count_button->unset_flags (Gtk::CAN_FOCUS);
@@ -348,15 +403,10 @@ CardView (VCard* card_)
 	 **--------------**
 	 */
 	SET_CV_TEXT(m_front_text);
-	SET_CV_SCROLLWIN(front_scrollwin,m_front_text);
+	set_cv_scrollwin(*front_scrollwin, *m_front_text);
+
 	SET_CV_LABEL(front_label);
-#ifndef IS_HILDON
-#if (GTKMM_MINOR_VERSION < 6)
-	front_label->set_text ("Q:");
-#else
-	front_label->set_angle (90.0);
-#endif
-#endif
+	Granule::rotate_label (front_label, 90.0, "Q:");
 	ft_alignment->add (*front_label);
 	vbox_frontlabel->pack_start (*ft_alignment, Gtk::PACK_SHRINK, 0);
 	
@@ -365,15 +415,9 @@ CardView (VCard* card_)
 	 **--------------**
 	 */
 	SET_CV_TEXT(m_back_text);
-	SET_CV_SCROLLWIN(backtext_scrollwin,m_back_text);
+	set_cv_scrollwin (*backtext_scrollwin, *m_back_text);
 	SET_CV_LABEL(back_label);
-#ifndef IS_HILDON
-#if (GTKMM_MAJOR_VERSION == 2 && GTKMM_MINOR_VERSION >= 6)
-	back_label->set_angle (90.0);
-#else
-	back_label->set_text ("A:");
-#endif
-#endif
+	Granule::rotate_label (back_label, 90.0, "A:");
 	bt_alignment->add (*back_label);
 	vbox_backlabel->pack_start (*bt_alignment, Gtk::PACK_SHRINK, 0);
 
@@ -382,15 +426,9 @@ CardView (VCard* card_)
 	 **----------------**
 	 */
 	SET_CV_TEXT(m_example_text);
-	SET_CV_SCROLLWIN(example_scrollwin,m_example_text);
+	set_cv_scrollwin (*example_scrollwin, *m_example_text);
 	SET_CV_LABEL(example_label);
-#ifndef IS_HILDON
-#if (GTKMM_MAJOR_VERSION == 2 && GTKMM_MINOR_VERSION >= 6)
-	example_label->set_angle (90.0);
-#else
-	example_label->set_text ("E:");
-#endif
-#endif
+	Granule::rotate_label (example_label, 90.0, "E:");
 	vbox_examplelabel->pack_start (*example_label, Gtk::PACK_SHRINK, 0);
 
 	/**------------------------------------**
@@ -402,16 +440,18 @@ CardView (VCard* card_)
 	asf_alignment->add (*asf_label);
 
 	hbox_asf->pack_start (*asf_alignment, Gtk::PACK_SHRINK, 0);
-	hbox_asf->pack_start (*m_asf_text, Gtk::PACK_EXPAND_WIDGET, 0);
-	hbox_asf->unset_flags (Gtk::CAN_FOCUS);
+	hbox_asf->pack_start (*(set_text_border (m_asf_text)), 
+						  Gtk::PACK_EXPAND_WIDGET, 0);
+	hbox_asf->unset_flags(Gtk::CAN_FOCUS);
 
 	SET_CV_TEXT(m_asb_text);
 	SET_CV_LABEL(asb_label);
 	asb_alignment->add (*asb_label);
 
 	hbox_asb->pack_start (*asb_alignment, Gtk::PACK_SHRINK, 0);
-	hbox_asb->pack_start (*m_asb_text, Gtk::PACK_EXPAND_WIDGET, 0);
-	hbox_asb->unset_flags (Gtk::CAN_FOCUS);
+	hbox_asb->pack_start (*(set_text_border (m_asb_text)), 
+						  Gtk::PACK_EXPAND_WIDGET, 0);
+	hbox_asb->unset_flags(Gtk::CAN_FOCUS);
 
 	/** Hook up callbacks
 	 */
@@ -442,8 +482,10 @@ CardView (VCard* card_)
 	/** Trap 'on virtual keyboard close' event to restore
 	 *  original size of the dialog
 	 */
+#ifdef HILDON_DEPRICATED
 	HILDONAPPWIN->signal_im_close ().connect (
 		mem_fun (*this, &CardView::hildon_im_close_cb));
+#endif
 #endif
 
 	/*************************************************
@@ -532,7 +574,7 @@ CardView (VCard* card_)
 	 */
 #if defined(IS_HILDON) || defined (IS_PDA)
 	Gtk::ScrolledWindow* scrollw = Gtk::manage (new Gtk::ScrolledWindow);
-	SET_CV_SCROLLWIN (scrollw, paned_1);
+	set_cv_scrollwin (*scrollw, *paned_1);
 	vbox_all->pack_start (*scrollw);
 #else                                      // Regular desktop 
 	vbox_all->pack_start (*paned_1);
@@ -643,14 +685,9 @@ run (bool disable_cancel_)
 	if (disable_cancel_) {
 		m_cancel_button->set_sensitive (false);
 	}
-	take_snapshot ();
 
-#ifdef IS_HILDON
-	GRANULE->register_appview (this);
-	Gtk::Main::run (*HILDONAPPWIN);
-#else
+	take_snapshot ();
 	Gtk::Main::run (*this);
-#endif
 
 	return (m_syntax_error ? Gtk::RESPONSE_REJECT : m_response);
 }
@@ -680,12 +717,7 @@ run (DeckView& deckview_)
 	take_snapshot ();
 	set_cards_count (deckview_);
 
-#ifdef IS_HILDON
-	GRANULE->register_appview (this);
-	Gtk::Main::run (*HILDONAPPWIN);
-#else
 	Gtk::Main::run (*this);
-#endif
 
 	DL ((GRAPP,"Processing syntax_error and response...\n"));
 
@@ -711,12 +743,8 @@ run (DeckView& deckview_)
 		DL ((GRAPP,"Looping ...\n"));
 		m_card = new Card;
 
-#ifdef IS_HILDON
-		GRANULE->register_appview (this);
-		Gtk::Main::run (*HILDONAPPWIN);
-#else
 		Gtk::Main::run (*this);
-#endif
+
 		if (m_syntax_error) {
 			delete m_card;
 			m_response = Gtk::RESPONSE_REJECT;
@@ -742,10 +770,6 @@ on_cancel_clicked  ()
 	
 	m_response = Gtk::RESPONSE_CANCEL;
 
-#ifdef IS_HILDON
-	GRANULE->unregister_appview (this);
-#endif
-
 	DL ((GRAPP,"Call Main::quit()\n"));
 	Gtk::Main::quit ();
 }
@@ -776,7 +800,11 @@ on_key_press_event (GdkEventKey* event_)
     /** Keep processing keystroke
 	 */
 #ifdef IS_HILDON
-	return Bin::on_key_press_event (event_);	
+#ifdef GLIBMM_VFUNCS_ENABLED
+	return Bin::on_key_press_event (event_);
+#else
+	return false;   // don't know how to handle for IT2007: HILDON_DEPRICATED
+#endif
 #else
 	return Window::on_key_press_event (event_);
 #endif
@@ -849,15 +877,8 @@ on_addnclose_clicked  ()
 	m_keep_open = false;
 	m_front_text->grab_focus ();
 
-#ifdef IS_HILDON
-	GRANULE->unregister_appview (this);
-
 	DL ((GRAPP,"Call Main::quit()\n"));
 	Gtk::Main::quit ();
-#else	
-	Gtk::Main::quit ();
-#endif
-	/* done */
 }
 
 void
@@ -902,7 +923,10 @@ on_help_clicked  ()
 {
 	trace_with_mask("CardView::on_help_clicked",GUITRACE);
 
-	m_help_dialog.show ();
+	if (m_help_dialog == NULL) {
+		m_help_dialog = Gtk::manage (new CardViewHelpDialog (*this));
+	}
+	m_help_dialog->show ();
 }
 
 void
