@@ -26,7 +26,7 @@ class Gtk::TextView;
 class Gtk::Entry;
 
 #ifdef IS_HILDON
-#    include <hildon-widgetsmm/appview.h>
+#    include <hildon-libsmm.h>
 #endif
 
 #include "Granule-main.h"
@@ -37,7 +37,11 @@ class DeckView;
 class EditControls;
 
 #ifdef IS_HILDON
-class CardView : public Hildon::AppView
+enum { TV_FRONT, TV_BACK, TV_EXAMPLE, TV_ASF, TV_ASB };
+#endif
+
+#ifdef IS_HILDON
+class CardView : public Hildon::Window
 #else
 class CardView : public Gtk::Window
 #endif
@@ -103,6 +107,13 @@ private:
 	Gtk::TextView*  m_asf_text;	    // Alt.Spell Front
 	Gtk::TextView*  m_asb_text;	    // Alt.Spell Back
 
+#ifdef IS_HILDON
+	/** Temporal fix - in hildon, Gtk::TextView doesn't allocate 
+	 *  default buffer.
+	 */ 
+	Glib::RefPtr<Gtk::TextBuffer> m_textbuf_ref[5];
+#endif
+
 	// -*- Snapshot to detect true changes -*-
 	//
 	Glib::ustring   m_snapshot_front;
@@ -111,11 +122,9 @@ private:
 	Glib::ustring   m_snapshot_asf;
 	Glib::ustring   m_snapshot_asb;
 
-	EditControls*   m_edit_controls;
-
-	CardViewHelpDialog m_help_dialog;
-
-	int             m_cards_count; // tied up to m_count_button
+	EditControls*       m_edit_controls;
+	CardViewHelpDialog* m_help_dialog;
+	int                 m_cards_count; // tied up to m_count_button
 };
 
 
