@@ -23,13 +23,8 @@
 
 #include "CardViewHelpDialog.h"
 
-
 CardViewHelpDialog::
-#ifdef IS_HILDON
-CardViewHelpDialog (Hildon::AppView& parent_)
-#else
 CardViewHelpDialog (Gtk::Window& parent_)
-#endif
 {  
 	trace_with_mask("CardViewHelpDialog::CardViewHelpDialog",GUITRACE);
 
@@ -44,40 +39,61 @@ CardViewHelpDialog (Gtk::Window& parent_)
 #ifndef IS_HILDON
 	m_dialog->set_transient_for (parent_);
 #endif
+
+#ifdef GLIBMM_PROPERTIES_ENABLED
 	m_dialog->property_window_position().set_value(Gtk::WIN_POS_CENTER_ON_PARENT);
+#else
+	m_dialog->set_property ("window_position", Gtk::WIN_POS_CENTER_ON_PARENT);
+#endif
 
 	m_vbox.set_homogeneous(false);
 	m_vbox.set_spacing(0);
 
 	m_close_button   = Gtk::manage (new Gtk::Button(Gtk::StockID("gtk-close")));
-	m_textview       = Gtk::manage (new Gtk::TextView());
 	m_scrolledwindow = Gtk::manage (new Gtk::ScrolledWindow());
 
-	m_close_button->set_flags(Gtk::CAN_FOCUS);
-	m_close_button->set_flags(Gtk::CAN_DEFAULT);
-	m_close_button->set_relief(Gtk::RELIEF_NORMAL);
+	m_textview = Gtk::manage (new Gtk::TextView());
 
-	m_textview->set_flags(Gtk::CAN_FOCUS);
-	m_textview->set_border_width(3);
-	m_textview->set_editable(false);
-	m_textview->set_cursor_visible(true);
-	m_textview->set_pixels_above_lines(2);
-	m_textview->set_pixels_below_lines(2);
-	m_textview->set_pixels_inside_wrap(2);
-	m_textview->set_left_margin(4);
-	m_textview->set_right_margin(4);
-	m_textview->set_indent(0);
-	m_textview->set_wrap_mode(Gtk::WRAP_WORD);
-	m_textview->set_justification(Gtk::JUSTIFY_LEFT);
+/** A bug either in Gtk+ or in Gtkmm on nokia 800 
+ *  doesn't allocate the default buffer.
+ */
+#ifdef IS_HILDON
+	m_textview = Gtk::manage (new Gtk::TextView ());
+	m_textbuf_ref = Gtk::TextBuffer::create();
+	m_textview->set_buffer (m_textbuf_ref);
+#endif
 
-	Glib::RefPtr<Gtk::TextBuffer> ref_textbuf = m_textview->get_buffer();
-	create_tags (ref_textbuf);
-	insert_text (ref_textbuf);
+	m_close_button->set_flags  (Gtk::CAN_FOCUS);
+	m_close_button->set_flags  (Gtk::CAN_DEFAULT);
+	m_close_button->set_relief (Gtk::RELIEF_NORMAL);
 
-	m_scrolledwindow->set_flags(Gtk::CAN_FOCUS);
-	m_scrolledwindow->set_shadow_type(Gtk::SHADOW_NONE);
-	m_scrolledwindow->set_policy(Gtk::POLICY_AUTOMATIC, Gtk::POLICY_ALWAYS);
-	m_scrolledwindow->property_window_placement().set_value(Gtk::CORNER_TOP_LEFT);
+	m_textview->set_flags (Gtk::CAN_FOCUS);
+	m_textview->set_border_width (3);
+	m_textview->set_editable (false);
+	m_textview->set_cursor_visible (true);
+	m_textview->set_pixels_above_lines (2);
+	m_textview->set_pixels_below_lines (2);
+	m_textview->set_pixels_inside_wrap (2);
+	m_textview->set_left_margin (4);
+	m_textview->set_right_margin (4);
+	m_textview->set_indent (0);
+	m_textview->set_wrap_mode (Gtk::WRAP_WORD);
+	m_textview->set_justification (Gtk::JUSTIFY_LEFT);
+
+	create_tags (m_textbuf_ref);
+	insert_text (m_textbuf_ref);
+
+	m_scrolledwindow->set_flags (Gtk::CAN_FOCUS);
+	m_scrolledwindow->set_shadow_type (Gtk::SHADOW_NONE);
+	m_scrolledwindow->set_policy (Gtk::POLICY_AUTOMATIC, Gtk::POLICY_ALWAYS);
+
+#ifdef GLIBMM_PROPERTIES_ENABLED
+	m_scrolledwindow->
+		property_window_placement().set_value(Gtk::CORNER_TOP_LEFT);
+#else
+	m_scrolledwindow->
+		set_property ("window_placement", Gtk::CORNER_TOP_LEFT);
+#endif
 	m_scrolledwindow->add(*m_textview);
 
 	m_vbox.set_homogeneous(false);
@@ -106,23 +122,47 @@ create_tags (Glib::RefPtr<Gtk::TextBuffer>& textbuf_)
 {
 	Glib::RefPtr<Gtk::TextBuffer::Tag> refTag;
 
-	textbuf_->create_tag("bold")->property_weight().set_value(Pango::WEIGHT_BOLD);
+	refTag = textbuf_->create_tag("bold");
+#ifdef GLIBMM_PROPERTIES_ENABLED
+	refTag->property_weight().set_value(Pango::WEIGHT_BOLD);
+#else
+	refTag->set_property ("weight", Pango::WEIGHT_BOLD);
+#endif
 
 	refTag = textbuf_->create_tag("monospace");
+#ifdef GLIBMM_PROPERTIES_ENABLED
 	refTag->property_scale().set_value(Pango::SCALE_X_SMALL);
 	refTag->property_family().set_value("monospace");
 	refTag->property_foreground().set_value("brown");
+#else
+//	refTag->set_property ("scale", Pango::SCALE_X_SMALL);
+	refTag->set_property ("family", Glib::ustring ("monospace"));
+	refTag->set_property ("foreground", Glib::ustring ("brown"));
+#endif
 
 	refTag = textbuf_->create_tag("heading");
+#ifdef GLIBMM_PROPERTIES_ENABLED
 	refTag->property_weight().set_value(Pango::WEIGHT_BOLD);
 	refTag->property_size().set_value(15 * Pango::SCALE);
 	refTag->property_foreground().set_value("blue");
+#else
+	refTag->set_property ("weight", Pango::WEIGHT_BOLD);
+	refTag->set_property ("size", (15 * Pango::SCALE));
+	refTag->set_property ("foreground", Glib::ustring ("blue"));
+#endif
 
 	refTag = textbuf_->create_tag("option_desc");
+#ifdef GLIBMM_PROPERTIES_ENABLED
     refTag->property_wrap_mode().set_value(Gtk::WRAP_WORD);
     refTag->property_indent().set_value(5);
     refTag->property_left_margin().set_value(40);
     refTag->property_right_margin().set_value(2);
+#else
+    refTag->set_property ("wrap_mode", Gtk::WRAP_WORD);
+    refTag->set_property ("indent", 5);
+    refTag->set_property ("left_margin", 40);
+    refTag->set_property ("right_margin", 2);
+#endif
 }
 
 void
@@ -141,7 +181,8 @@ insert_text (Glib::RefPtr<Gtk::TextBuffer>& buf_)
 	iter = buf_->insert (iter, "you try to learn. ");
 	iter = buf_->insert (iter, "Below is the summary of Pango Markup.\n\n");
 
-	iter = buf_->insert_with_tag (iter, "Pango Text Attribute Markup Language\n", "heading");
+	iter = buf_->insert_with_tag (iter, "Pango Text Attribute Markup Language\n", 
+								  "heading");
 
 	iter = buf_->insert (iter, "Frequently, you want to display some text ");
 	iter = buf_->insert (iter, "to the user with attributes applied to ");
@@ -149,11 +190,12 @@ insert_text (Glib::RefPtr<Gtk::TextBuffer>& buf_)
 	iter = buf_->insert (iter, "want bold or italicized words).\n\n");
 
 	iter = buf_->insert (iter, "Pango provides a small markup language for");
-	iter = buf_->insert (iter, "that. A simple example of a marked-up string might be: \n\n");
-	iter = buf_->insert_with_tag (iter, "\"<span foreground=\"blue\" size=\"x-large\">Blue text</span> is <i>cool</i>!\"", "monospace");
-	iter = buf_->insert (iter, "\n\n");
+	iter = buf_->insert (iter, "that. This simple example illustrates a possibile way to greately exhance the visual appeal of your flashcards:\n\n");
 
-	iter = buf_->insert_with_tag (iter, "<span> Attributes:\n", "heading");
+	iter = buf_->insert_with_tag (iter, "<span foreground=\"blue\" size=\"x-large\">Blue text</span> is <i>cool</i>!\n\n", "monospace");
+
+	iter = buf_->insert_with_tag (iter, "<span></span> Tag Attributes:\n", 
+								  "heading");
 
 	iter = buf_->insert_with_tag (iter, "font_desc\n", "bold");
 	iter = buf_->insert_with_tag (iter, "A font description string, such as \"Sans Italic 12\"; note that any other span attributes will override this description. So if you have \"Sans Italic\" and also a style=\"normal\" attribute, you will get Sans normal, not italic.\n", "option_desc");
@@ -206,17 +248,36 @@ insert_text (Glib::RefPtr<Gtk::TextBuffer>& buf_)
 
 	iter = buf_->insert_with_tag (iter, "lang\n", "bold");
 	iter = buf_->insert_with_tag (iter, "A language code, indicating the text language.\n\n", "option_desc");
-	iter = buf_->insert (iter, "The following convenience tags are provided:\n");
+	iter = buf_->insert (iter, "The following convenience tags similar to HTML markup language are provided. The tags can be nested.\n\n");
 
-	iter = buf_->insert_with_tag (iter, "Convenience tags\n", "heading");
+	iter = buf_->insert_with_tag (iter, "Convenience tags:\n\n", "heading");
 
-	iter = buf_->insert_with_tag (iter, "b      Bold \n", "option_desc");
-	iter = buf_->insert_with_tag (iter, "big    Makes font relatively larger\n", "option_desc");
-	iter = buf_->insert_with_tag (iter, "i      Italic\n", "option_desc");
-	iter = buf_->insert_with_tag (iter, "s      Strikethrough\n", "option_desc");
-	iter = buf_->insert_with_tag (iter, "sub    Subscript\n", "option_desc");
-	iter = buf_->insert_with_tag (iter, "sup    Superscript\n", "option_desc");
-	iter = buf_->insert_with_tag (iter, "small  Makes font relatively smaller\n", "option_desc");
-	iter = buf_->insert_with_tag (iter, "tt     Monospace font\n", "option_desc");
-	iter = buf_->insert_with_tag (iter, "u      Underline\n", "option_desc");
+	iter = buf_->insert_with_tag (iter, "<b></b>\n", "bold");
+	iter = buf_->insert_with_tag (iter, "Bold\n", "option_desc");
+
+	iter = buf_->insert_with_tag (iter, "<big></big>\n", "bold");
+	iter = buf_->insert_with_tag (iter, "Makes font relatively larger\n", 
+								  "option_desc");
+
+	iter = buf_->insert_with_tag (iter, "<i></i>\n", "bold");
+	iter = buf_->insert_with_tag (iter, "Italic\n", "option_desc");
+
+	iter = buf_->insert_with_tag (iter, "<s></s>\n", "bold");
+	iter = buf_->insert_with_tag (iter, "Strikethrough\n", "option_desc");
+
+	iter = buf_->insert_with_tag (iter, "<sub></sub>\n", "bold");
+	iter = buf_->insert_with_tag (iter, "Subscript\n", "option_desc");
+
+	iter = buf_->insert_with_tag (iter, "<sup></sup>\n", "bold");
+	iter = buf_->insert_with_tag (iter, "Superscript\n", "option_desc");
+
+	iter = buf_->insert_with_tag (iter, "<small></small>\n", "bold");
+	iter = buf_->insert_with_tag (iter, "Makes font relatively smaller\n", 
+								  "option_desc");
+
+	iter = buf_->insert_with_tag (iter, "<tt></tt>\n", "bold");
+	iter = buf_->insert_with_tag (iter, "Monospace font\n", "option_desc");
+
+	iter = buf_->insert_with_tag (iter, "<u></u>\n", "bold");
+	iter = buf_->insert_with_tag (iter, "Underline\n", "option_desc");
 }
