@@ -26,27 +26,25 @@
 
 
 #ifdef IS_HILDON
-#    include <hildon-widgetsmm/appview.h>
+#    include <hildon-libsmm.h>
 #endif
 
+#ifdef IS_HILDON
+class CardViewHelpDialog : public Hildon::Window
+#else
 class CardViewHelpDialog : public Gtk::Window
+#endif
 {  
 public:
-#ifdef IS_HILDON
-	CardViewHelpDialog (Hildon::AppView& parent_);
-#else
 	CardViewHelpDialog (Gtk::Window& parent_);
-#endif
 
 private:
 	void create_tags (Glib::RefPtr<Gtk::TextBuffer>& ref_buffer_);
 	void insert_text (Glib::RefPtr<Gtk::TextBuffer>& ref_buffer_);
 
 	void on_close_clicked () { hide (); }
-	virtual bool on_delete_event(GdkEventAny* any_)	{
-		hide ();
-		return false;
-	}
+
+	virtual bool on_delete_event(GdkEventAny* any_);
 
 private:
 	Gtk::Window*          m_dialog;
@@ -55,6 +53,18 @@ private:
 	Gtk::Button*          m_close_button;
 	Gtk::TextView*        m_textview;
 	Gtk::ScrolledWindow*  m_scrolledwindow;
+
+#ifdef IS_HILDON
+	Glib::RefPtr<Gtk::TextBuffer> m_textbuf_ref;
+#endif
 };
 
+inline bool
+CardViewHelpDialog::
+on_delete_event (GdkEventAny* any_)	
+{
+	hide ();
+	return false;
+}
+
 #endif
