@@ -1323,7 +1323,7 @@ play_card (SideSelection side_, Deck::cardlist_iterator& iter_)
 {
 	trace_with_mask("Deck::play_card",GUITRACE|DECK);
 
-	static char execmdbuf [1024];
+	static char execmdbuf [PATH_MAX];
 	std::vector<string> v;
 	string w;
 
@@ -1335,7 +1335,6 @@ play_card (SideSelection side_, Deck::cardlist_iterator& iter_)
 	DL ((GRAPP,"play card for side '%s'\n", (side_==FRONT?"Front":"Back")));
 
 	w = Granule::locale_from_utf8 ((*iter_)->get_alt_spelling (side_));
-
 	if (w.length () == 0) 
 	{
 		w = Granule::locale_from_utf8 ((*iter_)->get_question ());
@@ -1348,9 +1347,136 @@ play_card (SideSelection side_, Deck::cardlist_iterator& iter_)
 			w = v[1];
 		}
 	}
-	string sfn (m_active_snd_path + G_DIR_SEPARATOR_S);
-	sfn += w[0];
-	sfn += G_DIR_SEPARATOR_S + w; /// + ".wav";
+	
+	int n;
+	const char* cmd = CONFIG->get_snd_player_cmd ();
+
+	string sound_fname (m_active_snd_path + G_DIR_SEPARATOR_S);
+	sound_fname += w[0];
+	sound_fname += G_DIR_SEPARATOR_S + w; 
+	
+	string cmd_args (CONFIG->get_snd_player_args ());
+	string file_ext;
+
+// FIXME:
+//   This would not work any more because the type of the file 
+//   (and thus the whole name) is specified in the command line argument.
+//   But, without this check, what follows might cause a core dump.
+//   So, you need to fix it somehow!
+//
+//	struct stat st;
+//	if (::stat (sound_fname.c_str (), &st) != 0 || !S_ISREG (st.st_mode)) {
+//		DL((APP,"Can't stat sound file \"%s\"\n", sound_fname.c_str ()));
+//		return;
+//	}
+
+	DL((APP,"snd filename=\"%s\"\n", sound_fname.c_str ()));
+
+/**
+ * Win32
+ * -----
+ * If sound player command is an empty string, then use
+ * build-in system PlaySound() 
+ *   (FIXME: test it if it really works. Looks like you still need
+ *           the command arguments format to add the sound extension)
+ *      
+ * Otherwise, use the external command.
+ */
+	/** Arguments composition common for all
+	 */
+	snprintf (execmdbuf, PATH_MAX, cmd_args.c_str (), sound_fname.c_str ());
+
+#if defined (WIN32)
+	if (cmd != NULL && strlen (cmd) != 0) 
+	{
+		n = snprintf (execmdbuf, PATH_MAX, "\"%s\" ", cmd);
+		sprintf(execmdbuf+n, PATH_MAX-n, cmd_args.c_str(), sound_fname.c_str());
+		DL((GRAPP,"win32: system(\"%s\")\n", execmdbuf));
+		system (execmdbuf);
+	}
+	else {
+		DL((GRAPP,"win32: PlaySound(\"%s\")\n", execmdbuf));
+		PlaySound (execmdbuf, NULL, SND_FILENAME| SND_ASYNC);
+	}
+/**
+ * Hildon
+ * ------
+ * If sound command is an empty string, use build-in playback
+ * (this only works with WAV files and produces really bad quality 
+ *  sound).
+ *
+ * Otherwise, use DPS to play mp3 files with no impact on main CPU
+ * with this command:
+ *
+ *   gst-launch filesrc location=/path/to/your.mp3 ! dspmp3sink
+ *
+ * 
+ */
+#elif defined (IS_HILDON)
+	if (cmd != NULL && strlen (cmd) != 0) 
+	{
+		DL((APP,"hildon: fork_exec(\"%s %s\")\n", cmd, execmdbuf));
+//		ASSA::Fork::fork_exec (cmd, execmdbuf, ASSA::Fork::IGNORE_STATUS);
+		n = ASSA::Fork::fork_exec (cmd, execmdbuf, ASSA::Fork::COLLECT_STATUS);
+		DL((GRAPP,"forx_exec() = %d (0:success, 1:failed, -1:wait(2) failed\n",
+			n));
+	}
+	else {
+		DL((GRAPP,"hildon: hildon_play_system_sound(\"%s\")\n", execmdbuf));
+		hildon_play_system_sound (execmdbuf);
+	}
+/**
+ * POSIX (Desktops)
+ * ----------------
+ * For now, we squarely rely on external command
+ *
+ * FIXME: for the future, evaluate gstreamer framework.
+ *
+ *
+ */
+#else
+	/**	
+	 * NOTE: New Gtk 2.4 FileChooserDialog changes disposition mask for SIGCHLD.
+	 *       We have to preserve it - otherwise, we would crash and burn.
+	 *       COLLECT_STATUS option does that for us here.
+	*/
+	DL((APP,"posix: fork_exec(\"%s %s\")\n", cmd, execmdbuf));
+
+	ASSA::Fork::fork_exec (cmd, execmdbuf, ASSA::Fork::IGNORE_STATUS);
+#endif
+
+}
+
+// 	trace_with_mask("Deck::play_card",GUITRACE|DECK);
+
+// 	static char execmdbuf [1024];
+// 	std::vector<string> v;
+// 	string w;
+
+// 	if (!m_snd_enabled) {
+// 		DL ((GRAPP,"Sound is disabled!\n"));
+// 		return;
+// 	}
+
+// 	DL ((GRAPP,"play card for side '%s'\n", (side_==FRONT?"Front":"Back")));
+
+// 	w = Granule::locale_from_utf8 ((*iter_)->get_alt_spelling (side_));
+
+// 	if (w.length () == 0) 
+// 	{
+// 		w = Granule::locale_from_utf8 ((*iter_)->get_question ());
+// 		ASSA::Utils::split (w.c_str (), v);
+// 		if (v.size () > 1) 
+// 		{
+// 			if (v[0] != "to") {
+// 				return;
+// 			}
+// 			w = v[1];
+// 		}
+// 	}
+// 	string sfn (m_active_snd_path + G_DIR_SEPARATOR_S);
+// 	sfn += w[0];
+// 	sfn += G_DIR_SEPARATOR_S + w; /// + ".wav";
 
 //	struct stat st;
 //	if (::stat (sfn.c_str (), &st) != 0 || !S_ISREG (st.st_mode)) {
@@ -1358,49 +1484,49 @@ play_card (SideSelection side_, Deck::cardlist_iterator& iter_)
 //		return;
 //	}
 
-	DL((APP,"Play sound bite \"%s\"\n", sfn.c_str ()));
+// 	DL((APP,"Play sound bite \"%s\"\n", sfn.c_str ()));
 
-#if defined (WIN32)
+// #if defined (WIN32)
 
-	int n;
-	const char* cmd = CONFIG->get_snd_player_cmd ();
-	if (cmd != NULL && strlen (cmd) != 0) {
-		n = sprintf (execmdbuf, "\"%s\" ", cmd);
-		sprintf (execmdbuf+n, CONFIG->get_snd_player_args (), sfn.c_str ());
+// 	int n;
+// 	const char* cmd = CONFIG->get_snd_player_cmd ();
+// 	if (cmd != NULL && strlen (cmd) != 0) {
+// 		n = sprintf (execmdbuf, "\"%s\" ", cmd);
+// 		sprintf (execmdbuf+n, CONFIG->get_snd_player_args (), sfn.c_str ());
 
-		DL((GRAPP,"Win32: playing \"%s %s\"\n", execmdbuf));
-		system (execmdbuf);
-	}
-	else {
-		PlaySound (sfn.c_str (), NULL, SND_FILENAME| SND_ASYNC);
-	}
+// 		DL((GRAPP,"Win32: playing \"%s %s\"\n", execmdbuf));
+// 		system (execmdbuf);
+// 	}
+// 	else {
+// 		PlaySound (sfn.c_str (), NULL, SND_FILENAME| SND_ASYNC);
+// 	}
 
-#elif defined (IS_HILDON)
+// #elif defined (IS_HILDON)
 
-	snprintf (execmdbuf, 512, CONFIG->get_snd_player_args (), sfn.c_str ());
-	hildon_play_system_sound (execmdbuf);
+// 	snprintf (execmdbuf, 512, CONFIG->get_snd_player_args (), sfn.c_str ());
+// 	hildon_play_system_sound (execmdbuf);
 
-#else  /* POSIX */
+// #else  /* POSIX */
 
-	snprintf (execmdbuf, 512, CONFIG->get_snd_player_args (), sfn.c_str ());
+// 	snprintf (execmdbuf, 512, CONFIG->get_snd_player_args (), sfn.c_str ());
 
-	/**	
-	 * Better yet to route WAV playing through esd (if it is running):
-	 * esdplay <fname>.wav.
-	 *
-	 * NOTE: New Gtk 2.4 FileChooserDialog changes disposition mask for SIGCHLD.
-	 *       We have to preserve it - otherwise, we would crash and burn.
-	 *       COLLECT_STATUS option does that for us here.
-	*/
-	DL((APP,"POSIX: playing \"%s %s\"\n", 
-		CONFIG->get_snd_player_cmd (), execmdbuf));
+// 	/**	
+// 	 * Better yet to route WAV playing through esd (if it is running):
+// 	 * esdplay <fname>.wav.
+// 	 *
+// 	 * NOTE: New Gtk 2.4 FileChooserDialog changes disposition mask for SIGCHLD.
+// 	 *       We have to preserve it - otherwise, we would crash and burn.
+// 	 *       COLLECT_STATUS option does that for us here.
+// 	*/
+// 	DL((APP,"POSIX: playing \"%s %s\"\n", 
+// 		CONFIG->get_snd_player_cmd (), execmdbuf));
 
 
-	ASSA::Fork::fork_exec (CONFIG->get_snd_player_cmd (), 
-						   execmdbuf, ASSA::Fork::IGNORE_STATUS);
-#endif
-
-}
+// 	ASSA::Fork::fork_exec (CONFIG->get_snd_player_cmd (), 
+// 						   execmdbuf, ASSA::Fork::IGNORE_STATUS);
+// #endif
+//
+// }
 
 /** 
 	Deck information consists of two parts: the header (More... dialog)
