@@ -33,6 +33,10 @@
 using sigc::bind;
 using sigc::mem_fun;
 
+#ifdef IS_HILDON
+#   include <hildon-libsmm.h>
+#endif
+
 #include "ButtonWithImageLabel.h"
 
 #include "Granule-main.h"
@@ -553,10 +557,6 @@ Gtk::StockID DeckPlayer::THUMB_DOWN   ("thumb-down");
 DeckPlayer::
 DeckPlayer (VDeck& vdeck_) 
 		:
-#ifdef IS_HILDON
-	Hildon::AppView ("Deck Player"),
-	m_hildon_fullscreen (false),
-#endif
     m_close_button      (manage (new ButtonWithImageLabel (
 									 Gtk::Stock::CLOSE, _("Close")))),
 #ifdef IS_PDA
@@ -748,7 +748,13 @@ DeckPlayer (VDeck& vdeck_)
 	scrollw = Gtk::manage (new Gtk::ScrolledWindow);
 	scrollw->set_flags (Gtk::CAN_FOCUS);
 	scrollw->set_shadow_type (Gtk::SHADOW_NONE);
+
+#ifdef GLIBMM_PROPERTIES_ENABLED
 	scrollw->property_window_placement ().set_value (Gtk::CORNER_TOP_LEFT);
+#else
+	scrollw->set_property ("window_placement", Gtk::CORNER_TOP_LEFT);
+#endif
+
 	scrollw->set_policy (Gtk::POLICY_NEVER , Gtk::POLICY_AUTOMATIC);
 	scrollw->add (*m_question_box);
 
@@ -757,7 +763,7 @@ DeckPlayer (VDeck& vdeck_)
 
 	/***************************************************************************
 	 * Back of the card composition:                                           *
-	 *                                                                         *
+	 * ============================                                            *
 	 *  Notebook                                                               *
 	 *    +--Page                                                              *
 	 *         +--ScrolledWindow                                               *
@@ -767,6 +773,7 @@ DeckPlayer (VDeck& vdeck_)
 	 *                          +--EventBox                   <- modify_bg     *
 	 *                               +--HSeparator                             *
 	 *                          +--Label (m_example)          <- modify_fg     *
+	 *                                                                         *
      ***************************************************************************
 	 */
     m_answer_box = manage (new Gtk::VBox (false, ANSWER_BOX_SPACING));
@@ -774,10 +781,8 @@ DeckPlayer (VDeck& vdeck_)
 
     /* -Back (the answer)- 
 	 */
-	m_back.set_alignment  (x_alignment_enum (BACK),
-						   y_alignment_enum (BACK));
-	m_back.set_padding    (x_padding_val (BACK),
-						   y_padding_val (BACK));
+	m_back.set_alignment  (x_alignment_enum (BACK), y_alignment_enum (BACK));
+	m_back.set_padding    (x_padding_val (BACK), y_padding_val (BACK));
 	m_back.set_justify    (justification_enum (BACK));
 
     m_back.modify_font    (CONFIG->get_answer_font ());
@@ -837,9 +842,13 @@ DeckPlayer (VDeck& vdeck_)
 	scrollw = Gtk::manage (new Gtk::ScrolledWindow);
 	scrollw->set_flags (Gtk::CAN_FOCUS);
 	scrollw->set_shadow_type (Gtk::SHADOW_NONE);
-	scrollw->property_window_placement ().set_value (Gtk::CORNER_TOP_LEFT);
 	scrollw->set_policy (Gtk::POLICY_NEVER , Gtk::POLICY_AUTOMATIC);
 
+#ifdef GLIBMM_PROPERTIES_ENABLED
+	scrollw->property_window_placement ().set_value (Gtk::CORNER_TOP_LEFT);
+#else
+	scrollw->set_property ("window_placement", Gtk::CORNER_TOP_LEFT);
+#endif
 	scrollw->add (*viewport);
 
     m_notebook->pages ().push_back (
@@ -884,10 +893,10 @@ DeckPlayer (VDeck& vdeck_)
 	m_hs_button_ntb = manage (new Gtk::Button ());
 
 	m_hide_control = 
-		Gdk::Pixbuf::create_from_file (GRAPPDATDIR "/pixmaps/hide_control.png"
+		Granule::create_from_file (GRAPPDATDIR "/pixmaps/hide_control.png"
 									   DP_SHRINK_ICONS);
 	m_show_control = 
-		Gdk::Pixbuf::create_from_file (GRAPPDATDIR "/pixmaps/show_control.png"
+		Granule::create_from_file (GRAPPDATDIR "/pixmaps/show_control.png"
 									   DP_SHRINK_ICONS);
 
 #if (GTKMM_MAJOR_VERSION == 2 && GTKMM_MINOR_VERSION >= 6)
@@ -910,19 +919,21 @@ DeckPlayer (VDeck& vdeck_)
 	side_box->pack_start (*hs_vbox, Gtk::PACK_SHRINK, 0);
 #endif // (IS_PDA)
 
-    /** Side-panel buttons:
-	 *
-	 *    [<> Front ]
-	 *    [<> Back  ]
-	 *    [Test line: <1>]
-	 *    [Shuffle  ]
-	 *    [Edit Deck]
-	 *    [Edit Card]
-	 *
-	 * or for PDAs:
-	 *
-	 *    [%][<F>]<1> [Shuffle] [Edit Deck] [Edit Card]  [x Close]
-     */
+    /************************************************************************** 
+	 * Side-panel buttons:                                                    *
+	 * ==================                                                     *
+	 *    [<> Front ]                                                         *
+	 *    [<> Back  ]                                                         *
+	 *    [Test line: <1>]                                                    *
+	 *    [Shuffle  ]                                                         *
+	 *    [Edit Deck]                                                         *
+	 *    [Edit Card]                                                         *
+	 *                                                                        *
+	 * or for PDAs:                                                           *
+	 *                                                                        *
+	 *    [%][<F>]<1> [Shuffle] [Edit Deck] [Edit Card]  [x Close]            *
+	 *                                                                        *
+     **************************************************************************/
     side_box->pack_start (*sf_control,          Gtk::PACK_SHRINK, 0);
     side_box->pack_start (*m_test_line_entry,   Gtk::PACK_SHRINK, 0);
 
@@ -971,7 +982,7 @@ DeckPlayer (VDeck& vdeck_)
 
 	//------------------------------------------------------------------------
     m_playit_xpm = 
-		Gdk::Pixbuf::create_from_file (GRAPPDATDIR "/pixmaps/speaker_24.png");
+		Granule::create_from_file (GRAPPDATDIR "/pixmaps/speaker_24.png");
     Gtk::IconSet spkr_set;
     Gtk::IconSource spkr_source;
     spkr_source.set_pixbuf (m_playit_xpm);
@@ -981,7 +992,7 @@ DeckPlayer (VDeck& vdeck_)
     Gtk::Stock::add (Gtk::StockItem (DeckPlayer::SAY_IT, _("Say It!")));
 
 	Glib::RefPtr<Gdk::Pixbuf> thumbup_xpm = 
-		Gdk::Pixbuf::create_from_file (GRAPPDATDIR "/pixmaps/thumbup.png");
+		Granule::create_from_file (GRAPPDATDIR "/pixmaps/thumbup.png");
     Gtk::IconSet thumbup_set;
     Gtk::IconSource thumbup_source;
     thumbup_source.set_pixbuf (thumbup_xpm);
@@ -991,7 +1002,7 @@ DeckPlayer (VDeck& vdeck_)
     Gtk::Stock::add (Gtk::StockItem (DeckPlayer::THUMB_UP, _("I know it!")));
 
 	Glib::RefPtr<Gdk::Pixbuf> thumbdown_xpm = 
-		Gdk::Pixbuf::create_from_file (GRAPPDATDIR "/pixmaps/thumbdown.png");
+		Granule::create_from_file (GRAPPDATDIR "/pixmaps/thumbdown.png");
     Gtk::IconSet thumbdown_set;
     Gtk::IconSource thumbdown_source;
     thumbdown_source.set_pixbuf (thumbdown_xpm);
@@ -1062,7 +1073,13 @@ DeckPlayer (VDeck& vdeck_)
 			"  </toolbar>"
 			"</ui>";
 #endif
+#ifdef GLIBMM_EXCEPTOINS_ENABLED
 		m_uimanager->add_ui_from_string (ui_info);
+#else
+		std::auto_ptr<Glib::Error> err;
+		m_uimanager->add_ui_from_string (ui_info, err);
+#endif
+
     }
     catch (const Glib::Error& ex_) {
 		DL((GRAPP,"Building menues failed (%s)\n", ex_.what ().c_str ()));
@@ -1166,7 +1183,6 @@ DeckPlayer (VDeck& vdeck_)
     switch_side ();
 
     show_all_children ();	
-
 	m_initialized = true;
 }
 
@@ -1174,8 +1190,6 @@ DeckPlayer (VDeck& vdeck_)
 //                              Utilities
 //==============================================================================
 //
-
-
 gint
 DeckPlayer::
 run ()
@@ -1183,7 +1197,6 @@ run ()
     trace_with_mask("DeckPlayer::run",GUITRACE);
 
 #ifdef IS_HILDON
-	GRANULE->register_appview (this);
 	m_verify_control->set_focus_on_entry ();
 #endif
 
@@ -1195,18 +1208,13 @@ run ()
 	return (Gtk::RESPONSE_NONE);
 }
 
-
 void
 DeckPlayer::
 on_close_clicked ()
 {
     trace_with_mask("DeckPlayer::on_close_clicked",GUITRACE);
 
-#ifdef IS_HILDON
-	GRANULE->unregister_appview (this);
-#else
 	hide ();
-#endif
 
 	DL ((GRAPP,"Call Main::quit()\n"));
 	Gtk::Main::quit ();
@@ -1628,11 +1636,11 @@ on_edit_clicked ()
 		CARDBOX->mark_as_modified ();
 		show_card ();
 		
-#if !defined(IS_HILDON)
+//#if !defined(IS_HILDON)
 		/** Under Hildon, this messes up return chain.
 		 */
 		on_close_clicked ();
-#endif
+//#endif
     }
     else 
 	{
