@@ -32,7 +32,7 @@
 #include <gtkmm/table.h>
 
 #ifdef IS_HILDON
-#include <hildon-widgetsmm/appview.h>
+#include <hildon-libsmm.h>
 #endif
 
 #include "GrappConf.h"
@@ -161,7 +161,7 @@ private:
  **=============================================================================
  */
 #ifdef IS_HILDON 
-class DeckPlayer : public Hildon::AppView
+class DeckPlayer : public Hildon::Window
 #else
 class DeckPlayer : public Gtk::Window
 #endif
@@ -169,9 +169,9 @@ class DeckPlayer : public Gtk::Window
 public:
 	DeckPlayer (VDeck& vdeck_);
 
-//#ifdef IS_HILDON
+	/** Run the *dialog*
+	 */
 	gint run ();
-//#endif
 
 	/** Called in response to pressing <Close> button
 	 */
@@ -415,7 +415,9 @@ check_F6_key (gint keyval_)
 #ifdef IS_HILDON
 	if (keyval_ == GDK_F6) { // Full screen
 		m_hildon_fullscreen != m_hildon_fullscreen;
+#ifdef HILDON_DEPRICATED
 		set_fullscreen (m_hildon_fullscreen);
+#endif
 		return true;
 	}
 #endif
