@@ -53,7 +53,7 @@ DeckView::
 DeckView (VDeck& deck_, int selected_row_) 
 		:
 #ifdef IS_HILDON
-	Hildon::AppView    ("Deck View"),
+//	Hildon::Window    ("Deck View"),
 #endif
 	m_label_count      (manage (new Gtk::Label ("0 cards"))),
 	m_deck             (deck_),
@@ -171,7 +171,12 @@ DeckView (VDeck& deck_, int selected_row_)
 			"     <toolitem action='Save_Deck'/>"
 			"  </toolbar>"
 			"</ui>";
+#ifdef GLIBMM_EXCEPTOINS_ENABLED
 		m_uimanager->add_ui_from_string (ui_info);
+#else
+		std::auto_ptr<Glib::Error> err;
+		m_uimanager->add_ui_from_string (ui_info, err);
+#endif
     }
     catch (const Glib::Error& ex_) {
 		DL((GRAPP,"Building menues failed (%s)\n", ex_.what ().c_str ()));
@@ -253,9 +258,13 @@ DeckView (VDeck& deck_, int selected_row_)
 	renderer = Gtk::manage (new Gtk::CellRendererText);
 
 	column->pack_start (*renderer, false);
+#ifdef GLIBMM_PROPERTIES_ENABLED
 	column->add_attribute (renderer->property_markup (), 
 						   m_columns.m_front_row);
-						  
+#else
+	column->add_attribute (*renderer, "markup", m_columns.m_front_row);
+#endif
+
 	column->set_sizing (Gtk::TREE_VIEW_COLUMN_FIXED);
 	column->set_resizable ();
 #ifdef IS_PDA
@@ -267,7 +276,7 @@ DeckView (VDeck& deck_, int selected_row_)
 	/******************************
 	 * Enable column sorting
 	 ******************************/
-	column->set_sort_column_id (m_columns.m_front_row);
+	column->set_sort_column (m_columns.m_front_row);
 	column->set_sort_indicator (true);
 	column->signal_clicked ().connect (
 		mem_fun (*this, &DeckView::on_column_sorted));
@@ -280,8 +289,12 @@ DeckView (VDeck& deck_, int selected_row_)
 	renderer = Gtk::manage (new Gtk::CellRendererText);
 
 	column->pack_start (*renderer, false);
+#ifdef GLIBMM_PROPERTIES_ENABLED
 	column->add_attribute (renderer->property_markup (), 
 						   m_columns.m_back_row);
+#else
+	column->add_attribute (*renderer, "markup", m_columns.m_back_row);
+#endif
 
 	column->set_sizing (Gtk::TREE_VIEW_COLUMN_FIXED);
 	column->set_fixed_width (140);
@@ -289,7 +302,7 @@ DeckView (VDeck& deck_, int selected_row_)
 	/****************************
 	 * Enable column sorting
 	 ****************************/
-	column->set_sort_column_id (m_columns.m_back_row);
+	column->set_sort_column (m_columns.m_back_row);
 	column->set_sort_indicator (true);
 	column->signal_clicked ().connect (
 		mem_fun (*this, &DeckView::on_column_sorted));
@@ -419,10 +432,8 @@ run ()
 {
     trace_with_mask("DeckView::run",GUITRACE);
 
-#ifdef IS_HILDON
-	GRANULE->register_appview (this);
-#endif
 	Gtk::Main::run ();
+
 	return (Gtk::RESPONSE_NONE);
 }
 //#endif
@@ -433,10 +444,7 @@ on_close_clicked ()
 {
 	trace_with_mask("DeckView::on_close_clicked", GUITRACE);
 
-#ifdef IS_HILDON
 	hide ();
-	GRANULE->unregister_appview (this);
-#endif
 	DL ((GRAPP,"Call Main::quit()\n"));
 	Gtk::Main::quit ();
 }
@@ -467,7 +475,9 @@ on_card_selected ()
 	if (iter == pathlist.end ()) {
 		return;
 	}
-	m_row_idx = *((*iter).get_indices ().begin ());
+// Depricated
+//	m_row_idx = *((*iter).get_indices ().begin ());
+	m_row_idx = *((*iter).begin ());
 	DL((GRAPP,"Row selected : %d\n", m_row_idx));
 }
 
@@ -672,15 +682,15 @@ on_more_clicked ()
 {
 	trace_with_mask("DeckView::on_more_clicked", GUITRACE);
 
-#ifdef IS_HILDON
-	DeckInfo deck_info (*HILDONAPPWIN, dynamic_cast<Deck&>(m_deck));
-	deck_info.run ();
-	m_repaint_player = deck_info.appearance_changed ();
-#else
+//#ifdef IS_HILDON
+//	DeckInfo deck_info (*HILDONAPPWIN, dynamic_cast<Deck&>(m_deck));
+//	deck_info.run ();
+//	m_repaint_player = deck_info.appearance_changed ();
+//#else
 	DeckInfo deck_info (*this, dynamic_cast<Deck&>(m_deck));
 	deck_info.run ();
 	m_repaint_player = deck_info.appearance_changed ();
-#endif
+//#endif
 
 }
 
@@ -831,7 +841,8 @@ on_add_card_to_cardbox ()
 	pathlist_iterator_t iter = pathlist.begin ();
 	while (iter != pathlist.end ()) 
 	{
-		row_idx = *((*iter).get_indices ().begin ());
+//		row_idx = *((*iter).get_indices ().begin ());
+		row_idx = *((*iter).begin ());
 		card_iter = m_deck.begin () + row_idx;
 		card_list.push_back (new CardRef (**card_iter, 
 										  dynamic_cast<Deck&>(m_deck)));
