@@ -22,6 +22,7 @@
 #include <gtkmm/iconfactory.h>
 
 #include "Granule-main.h"
+#include "Granule.h"
 #include "EditControls.h"
 #include "MyInputDialog.h"
 
@@ -63,9 +64,10 @@ add_icon_to_factory (Glib::RefPtr<Gtk::IconFactory>& ifactory_,
  */
 EditControls::
 EditControls (Glib::RefPtr<Gtk::TextBuffer> tb_ref_)
-	: Gtk::HBox (false, 0), 
-	  m_textbuf (tb_ref_),
-	  m_index_count (1)
+	: 
+	Gtk::HBox (false, 0), 
+	m_textbuf (tb_ref_),
+	m_index_count (1)
 {
 	trace_with_mask("EditControls::EditControls", GUITRACE);
 
@@ -73,84 +75,84 @@ EditControls (Glib::RefPtr<Gtk::TextBuffer> tb_ref_)
 	Glib::RefPtr<Gdk::Pixbuf> pixbuf_ref;
 	Glib::RefPtr<Gtk::IconFactory> ifactory = Gtk::IconFactory::create ();
 
-	pixbuf_ref = Gdk::Pixbuf::create_from_file (
+	pixbuf_ref = Granule::create_from_file (
 		GRAPPDATDIR "pixmaps/text_bold.png");
 	add_icon_to_factory (ifactory, pixbuf_ref, EditControls::BOLD);
 	m_icon_list.push_back (icon_t (EditControls::BOLD,
 								   manage (new Image (pixbuf_ref)),
 								   "Apply bold tag"));
 	
-	pixbuf_ref = Gdk::Pixbuf::create_from_file (
+	pixbuf_ref = Granule::create_from_file (
 		GRAPPDATDIR "pixmaps/text_italic.png");
 	add_icon_to_factory (ifactory, pixbuf_ref, EditControls::ITALIC);
 	m_icon_list.push_back (icon_t (EditControls::ITALIC,
 								   manage (new Image (pixbuf_ref)),
 								   "Apply italic tag"));
 
-	pixbuf_ref = Gdk::Pixbuf::create_from_file (
+	pixbuf_ref = Granule::create_from_file (
 		GRAPPDATDIR "pixmaps/text_underlined.png");
 	add_icon_to_factory (ifactory, pixbuf_ref, EditControls::UNDERLINE);
 	m_icon_list.push_back (icon_t (EditControls::UNDERLINE,
 								   manage (new Image (pixbuf_ref)),
 								   "Apply underline tag"));
 
-	pixbuf_ref = Gdk::Pixbuf::create_from_file (
+	pixbuf_ref = Granule::create_from_file (
 		GRAPPDATDIR "pixmaps/text_monospaced.png");
 	add_icon_to_factory (ifactory, pixbuf_ref, EditControls::MONOSPACE);
 	m_icon_list.push_back (icon_t (EditControls::MONOSPACE,
 								   manage (new Image (pixbuf_ref)),
 								   "Apply monospace tag"));
 
-	pixbuf_ref = Gdk::Pixbuf::create_from_file (
+	pixbuf_ref = Granule::create_from_file (
 		GRAPPDATDIR "pixmaps/text_subscript.png");
 	add_icon_to_factory (ifactory, pixbuf_ref, EditControls::SUBSCRIPT);
 	m_icon_list.push_back (icon_t (EditControls::SUBSCRIPT,
 								   manage (new Image (pixbuf_ref)),
 								   "Apply subscript tag"));
 
-	pixbuf_ref = Gdk::Pixbuf::create_from_file (
+	pixbuf_ref = Granule::create_from_file (
 		GRAPPDATDIR "pixmaps/text_superscript.png");
 	add_icon_to_factory (ifactory, pixbuf_ref, EditControls::SUPERSCRIPT);
 	m_icon_list.push_back (icon_t (EditControls::SUPERSCRIPT,
 								   manage (new Image (pixbuf_ref)),
 								   "Apply superscript tag"));
 
-	pixbuf_ref = Gdk::Pixbuf::create_from_file (
+	pixbuf_ref = Granule::create_from_file (
 		GRAPPDATDIR "pixmaps/text_big.png");
 	add_icon_to_factory (ifactory, pixbuf_ref, EditControls::BIG);
 	m_icon_list.push_back (icon_t (EditControls::BIG,
 								   manage (new Image (pixbuf_ref)),
 								   "Make selection bigger"));
 
-	pixbuf_ref = Gdk::Pixbuf::create_from_file (
+	pixbuf_ref = Granule::create_from_file (
 		GRAPPDATDIR "pixmaps/text_small.png");
 	add_icon_to_factory (ifactory, pixbuf_ref, EditControls::SMALL);
 	m_icon_list.push_back (icon_t (EditControls::SMALL,
 								   manage (new Image (pixbuf_ref)),
 								   "Make selection smaller"));
 
-	pixbuf_ref = Gdk::Pixbuf::create_from_file (
+	pixbuf_ref = Granule::create_from_file (
 		GRAPPDATDIR "pixmaps/text_remove_tags.png");
 	add_icon_to_factory (ifactory, pixbuf_ref, EditControls::REMOVETAGS);
 	m_icon_list.push_back (icon_t (EditControls::REMOVETAGS,
 								   manage (new Image (pixbuf_ref)),
 								   "Remove all tags"));
 
-	pixbuf_ref = Gdk::Pixbuf::create_from_file (
+	pixbuf_ref = Granule::create_from_file (
 		GRAPPDATDIR "pixmaps/text_paste.png");
 	add_icon_to_factory (ifactory, pixbuf_ref, EditControls::PASTE);
 	m_icon_list.push_back (icon_t (EditControls::PASTE,
 								   manage (new Image (pixbuf_ref)),
 								   "Paste from clipboard"));
 
-	pixbuf_ref = Gdk::Pixbuf::create_from_file (
+	pixbuf_ref = Granule::create_from_file (
 		GRAPPDATDIR "pixmaps/text_normalize.png");
 	add_icon_to_factory (ifactory, pixbuf_ref, EditControls::NORMALIZE);
 	m_icon_list.push_back (icon_t (EditControls::NORMALIZE,
 								   manage (new Image (pixbuf_ref)),
 								   "Remove extra spaces and newlines"));
 
-	pixbuf_ref = Gdk::Pixbuf::create_from_file (
+	pixbuf_ref = Granule::create_from_file (
 		GRAPPDATDIR "pixmaps/text_addindex.png");
 	add_icon_to_factory (ifactory, pixbuf_ref, EditControls::ADDINDEX);
 	m_icon_list.push_back (icon_t (EditControls::ADDINDEX,
@@ -207,7 +209,13 @@ EditControls (Glib::RefPtr<Gtk::TextBuffer> tb_ref_)
 			"     <toolitem action='add_index'/>"
 			"  </toolbar>"
 			"</ui>";
+
+#ifdef GLIBMM_EXCEPTOINS_ENABLED
 		m_uimanager->add_ui_from_string (ui_info);
+#else
+		std::auto_ptr<Glib::Error> err;
+		m_uimanager->add_ui_from_string (ui_info, err);
+#endif
     }
     catch (const Glib::Error& ex_) {
 		DL((GRAPP,"Building menues failed (%s)\n", ex_.what ().c_str ()));
@@ -222,6 +230,19 @@ EditControls (Glib::RefPtr<Gtk::TextBuffer> tb_ref_)
 	/** Pack all up
 	 */
 	this->pack_start (*ctrl_toolbar, Gtk::PACK_EXPAND_WIDGET, 0);
+	
+	/** See if we can defeat default theme of Hildon
+	 */
+#ifdef IS_HILDON
+#ifdef NICE_TRY
+	Gdk::Color box_bgcolor ("grey");
+	Glib::RefPtr<Gtk::Style> style = get_style ();
+	style->set_base (Gtk::STATE_NORMAL, box_bgcolor);
+	style->set_bg   (Gtk::STATE_NORMAL, box_bgcolor);
+	style->set_fg   (Gtk::STATE_NORMAL, box_bgcolor);
+	set_style (style);
+#endif
+#endif
 }
 
 void
