@@ -18,7 +18,7 @@
 #include <gtkmm/notebook.h>
 
 #ifdef IS_HILDON
-#    include <hildon-widgetsmm/appview.h>
+#    include <hildon-libsmm.h>
 #endif
 
 #include "Granule-main.h"
@@ -28,7 +28,7 @@
  Class 
 *******************************************************************************/
 #ifdef IS_HILDON
-class MyPropertyBox : public Hildon::AppView
+class MyPropertyBox : public Hildon::Window
 #else
 class MyPropertyBox : public Gtk::Dialog
 #endif
