@@ -78,13 +78,7 @@ run ()
 	m_apply_button->set_sensitive (false);
 
     show ();
-
-#ifdef IS_HILDON
-	GRANULE->register_appview (this);
-	Gtk::Main::run (*HILDONAPPWIN);
-#else
     Gtk::Main::run ();
-#endif
 
     return m_changed;
 }
